@@ -97,7 +97,7 @@ void closeAudio(void);
 void pauseAudio(void);
 void resumeAudio(void);
 bool setNewAudioSettings(void);
-void resetDitherSeed(void);
+void resetAudioDither(void);
 void lockAudio(void);
 void unlockAudio(void);
 void lockMixerCallback(void);
