@@ -252,7 +252,7 @@ static bool testEditKeys(SDL_Scancode scancode, SDL_Keycode keycode)
 
 	pattLen = pattLens[editor.editPattern];
 	if (playMode == PLAYMODE_EDIT && pattLen >= 1)
-		setPos(-1, (editor.pattPos + editor.ID_Add) % pattLen);
+		setPos(-1, (editor.pattPos + editor.ID_Add) % pattLen, true);
 
 	if (i == 0) // if we inserted a zero, check if pattern is empty, for killing
 		killPatternIfUnused(editor.editPattern);
@@ -438,7 +438,13 @@ void recordNote(uint8_t note, int8_t vol)
 		editor.keyOnTab[c] = note;
 
 		if (pattpos >= oldpattpos) // non-FT2 fix: only do this if we didn't quantize to next row
+		{
+#ifdef HAS_MIDI
 			playTone(c, editor.curInstr, note, vol, midi.currMIDIVibDepth, midi.currMIDIPitch);
+#else
+			playTone(c, editor.curInstr, note, vol, 0, 0);
+#endif
+		}
 
 		if (editmode || recmode)
 		{
@@ -459,7 +465,7 @@ void recordNote(uint8_t note, int8_t vol)
 				{
 					// increase row (only in edit mode)
 					if (pattLen >= 1)
-						setPos(-1, (editor.pattPos + editor.ID_Add) % pattLen);
+						setPos(-1, (editor.pattPos + editor.ID_Add) % pattLen, true);
 				}
 				else
 				{
@@ -490,7 +496,13 @@ void recordNote(uint8_t note, int8_t vol)
 		editor.keyOffTime[c] = ++editor.keyOffNr;
 
 		if (pattpos >= oldpattpos) // non-FT2 fix: only do this if we didn't quantize to next row
+		{
+#ifdef HAS_MIDI
 			playTone(c, editor.curInstr, 97, vol, midi.currMIDIVibDepth, midi.currMIDIPitch);
+#else
+			playTone(c, editor.curInstr, 97, vol, 0, 0);
+#endif
+		}
 
 		if (config.recRelease && recmode)
 		{
@@ -524,7 +536,7 @@ void recordNote(uint8_t note, int8_t vol)
 				{
 					// increase row (only in edit mode)
 					if (pattLen >= 1)
-						setPos(-1, (editor.pattPos + editor.ID_Add) % pattLen);
+						setPos(-1, (editor.pattPos + editor.ID_Add) % pattLen, true);
 				}
 				else
 				{
@@ -598,7 +610,7 @@ bool handleEditKeys(SDL_Keycode keycode, SDL_Scancode scancode)
 		// increase row (only in edit mode)
 		pattLen = pattLens[editor.editPattern];
 		if (playMode == PLAYMODE_EDIT && pattLen >= 1)
-			setPos(-1, (editor.pattPos + editor.ID_Add) % pattLen);
+			setPos(-1, (editor.pattPos + editor.ID_Add) % pattLen, true);
 
 		editor.ui.updatePatternEditor = true;
 		setSongModifiedFlag();
@@ -673,7 +685,7 @@ void writeFromMacroSlot(uint8_t slot)
 	}
 
 	if (playMode == PLAYMODE_EDIT && pattLen >= 1)
-		setPos(-1, (editor.pattPos + editor.ID_Add) % pattLen);
+		setPos(-1, (editor.pattPos + editor.ID_Add) % pattLen, true);
 
 	killPatternIfUnused(editor.editPattern);
 
@@ -723,35 +735,30 @@ void insertPatternLine(void)
 
 	nr = editor.editPattern;
 
-	if (setPatternLen(nr, pattLens[nr] + config.recTrueInsert)) // config.recTrueInsert is 0 or 1
+	setPatternLen(nr, pattLens[nr] + config.recTrueInsert); // config.recTrueInsert is 0 or 1
+
+	pattPtr = patt[nr];
+	if (pattPtr != NULL)
 	{
-		pattPtr = patt[nr];
-		if (pattPtr != NULL)
+		pattPos = editor.pattPos;
+		pattLen = pattLens[nr];
+
+		if (pattLen > 1)
 		{
-			pattPos = editor.pattPos;
-			pattLen = pattLens[nr];
-
-			if (pattLen > 1)
+			for (int32_t i = pattLen-2; i >= pattPos; i--)
 			{
-				for (int32_t i = pattLen-2; i >= pattPos; i--)
-				{
-					for (int32_t j = 0; j < MAX_VOICES; j++)
-						pattPtr[((i + 1) * MAX_VOICES) + j] = pattPtr[(i * MAX_VOICES) + j];
-				}
+				for (int32_t j = 0; j < MAX_VOICES; j++)
+					pattPtr[((i + 1) * MAX_VOICES) + j] = pattPtr[(i * MAX_VOICES) + j];
 			}
-
-			memset(&pattPtr[pattPos * MAX_VOICES], 0, TRACK_WIDTH);
-
-			killPatternIfUnused(nr);
 		}
 
-		editor.ui.updatePatternEditor = true;
-		setSongModifiedFlag();
-	}
-	else
-	{
-		okBox(0, "System message", "Not enough memory!");
+		memset(&pattPtr[pattPos * MAX_VOICES], 0, TRACK_WIDTH);
+
+		killPatternIfUnused(nr);
 	}
+
+	editor.ui.updatePatternEditor = true;
+	setSongModifiedFlag();
 }
 
 void deletePatternNote(void)
@@ -1851,7 +1858,7 @@ static bool askForScaleFade(char *msg)
 	uint8_t err;
 
 	sprintf(volstr, "%0.2f,%0.2f", dVolScaleFK1, dVolScaleFK2);
-	if (inputBox(2, msg, volstr, sizeof (volstr) - 1) != 1)
+	if (inputBox(1, msg, volstr, sizeof (volstr) - 1) != 1)
 		return false;
 
 	err = false;
