@@ -49,7 +49,8 @@ void unstuckLastUsedGUIElement(void)
 	if (mouse.lastUsedObjectID == OBJECT_ID_NONE)
 	{
 		/* if last object ID is OBJECT_ID_NONE, check if we moved the
-		** sample data loop pins, and unstuck them if so */
+		** sample data loop pins, and unstuck them if so
+		*/
 
 		if (editor.ui.leftLoopPinMoving)
 		{
@@ -312,10 +313,13 @@ void charOut(uint16_t xPos, uint16_t yPos, uint8_t paletteIndex, char chr)
 {
 	const uint8_t *srcPtr;
 	uint32_t *dstPtr, pixVal;
+#ifndef __arm__
+	uint32_t tmp;
+#endif
 
 	assert(xPos < SCREEN_W && yPos < SCREEN_H);
 
-	chr &= 0x7F;
+	chr &= 0x7F; // this is important to get the nordic glyphs in the font
 	if (chr == ' ')
 		return;
 
@@ -327,8 +331,15 @@ void charOut(uint16_t xPos, uint16_t yPos, uint8_t paletteIndex, char chr)
 	{
 		for (uint32_t x = 0; x < FONT1_CHAR_W; x++)
 		{
-			if (srcPtr[x])
+#ifdef __arm__
+			if (srcPtr[x] != 0)
 				dstPtr[x] = pixVal;
+#else
+			// carefully written like this to generate conditional move instructions (font data is hard to predict)
+			tmp = dstPtr[x];
+			if (srcPtr[x] != 0) tmp = pixVal;
+			dstPtr[x] = tmp;
+#endif
 		}
 
 		srcPtr += FONT1_WIDTH;
@@ -343,7 +354,7 @@ void charOutBg(uint16_t xPos, uint16_t yPos, uint8_t fgPalette, uint8_t bgPalett
 
 	assert(xPos < SCREEN_W && yPos < SCREEN_H);
 
-	chr &= 0x7F;
+	chr &= 0x7F; // this is important to get the nordic glyphs in the font
 	if (chr == ' ')
 		return;
 
@@ -355,8 +366,8 @@ void charOutBg(uint16_t xPos, uint16_t yPos, uint8_t fgPalette, uint8_t bgPalett
 
 	for (uint32_t y = 0; y < FONT1_CHAR_H; y++)
 	{
-		for (uint32_t x = 0; x < 7; x++)
-			dstPtr[x] = srcPtr[x] ? fg : bg;
+		for (uint32_t x = 0; x < FONT1_CHAR_W-1; x++)
+			dstPtr[x] = srcPtr[x] ? fg : bg; // compiles nicely into conditional move instructions
 
 		srcPtr += FONT1_WIDTH;
 		dstPtr += SCREEN_W;
@@ -376,32 +387,48 @@ void charOutOutlined(uint16_t x, uint16_t y, uint8_t paletteIndex, char chr)
 void charOutShadow(uint16_t xPos, uint16_t yPos, uint8_t paletteIndex, uint8_t shadowPaletteIndex, char chr)
 {
 	const uint8_t *srcPtr;
-	uint32_t *dstPtr, pixVal1, pixVal2;
+	uint32_t *dstPtr1, *dstPtr2, pixVal1, pixVal2;
+#ifndef __arm__
+	uint32_t tmp;
+#endif
 
 	assert(xPos < SCREEN_W && yPos < SCREEN_H);
 
-	chr &= 0x7F;
+	chr &= 0x7F; // this is important to get the nordic glyphs in the font
 	if (chr == ' ')
 		return;
 
 	pixVal1 = video.palette[paletteIndex];
 	pixVal2 = video.palette[shadowPaletteIndex];
-	srcPtr  = &font1Data[chr * FONT1_CHAR_W];
-	dstPtr  = &video.frameBuffer[(yPos * SCREEN_W) + xPos];
+	srcPtr = &font1Data[chr * FONT1_CHAR_W];
+	dstPtr1 = &video.frameBuffer[(yPos * SCREEN_W) + xPos];
+	dstPtr2 = dstPtr1 + (SCREEN_W+1);
 
 	for (uint32_t y = 0; y < FONT1_CHAR_H; y++)
 	{
 		for (uint32_t x = 0; x < FONT1_CHAR_W; x++)
 		{
-			if (srcPtr[x])
+#ifdef __arm__
+			if (srcPtr[x] != 0)
 			{
-				dstPtr[x+(SCREEN_W+1)] = pixVal2;
-				dstPtr[x] = pixVal1;
+				dstPtr2[x] = pixVal2;
+				dstPtr1[x] = pixVal1;
 			}
+#else
+			// carefully written like this to generate conditional move instructions (font data is hard to predict)
+			tmp = dstPtr2[x];
+			if (srcPtr[x] != 0) tmp = pixVal2;
+			dstPtr2[x] = tmp;
+
+			tmp = dstPtr1[x];
+			if (srcPtr[x] != 0) tmp = pixVal1;
+			dstPtr1[x] = tmp;
+#endif
 		}
 
 		srcPtr += FONT1_WIDTH;
-		dstPtr += SCREEN_W;
+		dstPtr1 += SCREEN_W;
+		dstPtr2 += SCREEN_W;
 	}
 }
 
@@ -410,13 +437,16 @@ void charOutClipX(uint16_t xPos, uint16_t yPos, uint8_t paletteIndex, char chr,
 	const uint8_t *srcPtr;
 	uint16_t width;
 	uint32_t *dstPtr, pixVal;
+#ifndef __arm__
+	uint32_t tmp;
+#endif
 
 	assert(xPos < SCREEN_W && yPos < SCREEN_H);
 
 	if (xPos > clipX)
 		return;
 
-	chr &= 0x7F;
+	chr &= 0x7F; // this is important to get the nordic glyphs in the font
 	if (chr == ' ')
 		return;
 
@@ -432,8 +462,15 @@ void charOutClipX(uint16_t xPos, uint16_t yPos, uint8_t paletteIndex, char chr,
 	{
 		for (uint32_t x = 0; x < width; x++)
 		{
-			if (srcPtr[x])
+#ifdef __arm__
+			if (srcPtr[x] != 0)
 				dstPtr[x] = pixVal;
+#else
+			// carefully written like this to generate conditional move instructions (font data is hard to predict)
+			tmp = dstPtr[x];
+			if (srcPtr[x] != 0) tmp = pixVal;
+			dstPtr[x] = tmp;
+#endif
 		}
 
 		srcPtr += FONT1_WIDTH;
@@ -445,10 +482,13 @@ void bigCharOut(uint16_t xPos, uint16_t yPos, uint8_t paletteIndex, char chr)
 {
 	const uint8_t *srcPtr;
 	uint32_t *dstPtr, pixVal;
+#ifndef __arm__
+	uint32_t tmp;
+#endif
 
 	assert(xPos < SCREEN_W && yPos < SCREEN_H);
 
-	chr &= 0x7F;
+	chr &= 0x7F; // this is important to get the nordic glyphs in the font
 	if (chr == ' ')
 		return;
 
@@ -460,8 +500,15 @@ void bigCharOut(uint16_t xPos, uint16_t yPos, uint8_t paletteIndex, char chr)
 	{
 		for (uint32_t x = 0; x < FONT2_CHAR_W; x++)
 		{
-			if (srcPtr[x])
+#ifdef __arm__
+			if (srcPtr[x] != 0)
 				dstPtr[x] = pixVal;
+#else
+			// carefully written like this to generate conditional move instructions (font data is hard to predict)
+			tmp = dstPtr[x];
+			if (srcPtr[x] != 0) tmp = pixVal;
+			dstPtr[x] = tmp;
+#endif
 		}
 
 		srcPtr += FONT2_WIDTH;
@@ -472,32 +519,48 @@ void bigCharOut(uint16_t xPos, uint16_t yPos, uint8_t paletteIndex, char chr)
 static void bigCharOutShadow(uint16_t xPos, uint16_t yPos, uint8_t paletteIndex, uint8_t shadowPaletteIndex, char chr)
 {
 	const uint8_t *srcPtr;
-	uint32_t *dstPtr, pixVal1, pixVal2;
+	uint32_t *dstPtr1, *dstPtr2, pixVal1, pixVal2;
+#ifndef __arm__
+	uint32_t tmp;
+#endif
 
 	assert(xPos < SCREEN_W && yPos < SCREEN_H);
 
-	chr &= 0x7F;
+	chr &= 0x7F; // this is important to get the nordic glyphs in the font
 	if (chr == ' ')
 		return;
 
 	pixVal1 = video.palette[paletteIndex];
 	pixVal2 = video.palette[shadowPaletteIndex];
-	srcPtr  = &font2Data[chr * FONT2_CHAR_W];
-	dstPtr  = &video.frameBuffer[(yPos * SCREEN_W) + xPos];
+	srcPtr = &font2Data[chr * FONT2_CHAR_W];
+	dstPtr1 = &video.frameBuffer[(yPos * SCREEN_W) + xPos];
+	dstPtr2 = dstPtr1 + (SCREEN_W+1);
 
 	for (uint32_t y = 0; y < FONT2_CHAR_H; y++)
 	{
 		for (uint32_t x = 0; x < FONT2_CHAR_W; x++)
 		{
-			if (srcPtr[x])
+#ifdef __arm__
+			if (srcPtr[x] != 0)
 			{
-				dstPtr[x+(SCREEN_W+1)] = pixVal2;
-				dstPtr[x] = pixVal1;
+				dstPtr2[x] = pixVal2;
+				dstPtr1[x] = pixVal1;
 			}
+#else
+			// carefully written like this to generate conditional move instructions (font data is hard to predict)
+			tmp = dstPtr2[x];
+			if (srcPtr[x] != 0) tmp = pixVal2;
+			dstPtr2[x] = tmp;
+
+			tmp = dstPtr1[x];
+			if (srcPtr[x] != 0) tmp = pixVal1;
+			dstPtr1[x] = tmp;
+#endif
 		}
 
 		srcPtr += FONT2_WIDTH;
-		dstPtr += SCREEN_W;
+		dstPtr1 += SCREEN_W;
+		dstPtr2 += SCREEN_W;
 	}
 }
 
@@ -633,6 +696,9 @@ void hexOut(uint16_t xPos, uint16_t yPos, uint8_t paletteIndex, uint32_t val, ui
 {
 	const uint8_t *srcPtr;
 	uint32_t *dstPtr, pixVal;
+#ifndef __arm__
+	uint32_t tmp;
+#endif
 
 	assert(xPos < SCREEN_W && yPos < SCREEN_H);
 
@@ -648,8 +714,15 @@ void hexOut(uint16_t xPos, uint16_t yPos, uint8_t paletteIndex, uint32_t val, ui
 		{
 			for (uint32_t x = 0; x < FONT6_CHAR_W; x++)
 			{
-				if (srcPtr[x])
+#ifdef __arm__
+				if (srcPtr[x] != 0)
 					dstPtr[x] = pixVal;
+#else
+				// carefully written like this to generate conditional move instructions (font data is hard to predict)
+				tmp = dstPtr[x];
+				if (srcPtr[x] != 0) tmp = pixVal;
+				dstPtr[x] = tmp;
+#endif
 			}
 
 			srcPtr += FONT6_WIDTH;
@@ -680,7 +753,7 @@ void hexOutBg(uint16_t xPos, uint16_t yPos, uint8_t fgPalette, uint8_t bgPalette
 		for (uint32_t y = 0; y < FONT6_CHAR_H; y++)
 		{
 			for (uint32_t x = 0; x < FONT6_CHAR_W; x++)
-				dstPtr[x] = srcPtr[x] ? fg : bg;
+				dstPtr[x] = srcPtr[x] ? fg : bg; // compiles nicely into conditional move instructions
 
 			srcPtr += FONT6_WIDTH;
 			dstPtr += SCREEN_W;
@@ -815,7 +888,7 @@ void vLine(uint16_t x, uint16_t y, uint16_t h, uint8_t paletteIndex)
 	dstPtr = &video.frameBuffer[(y * SCREEN_W) + x];
 	for (uint32_t i = 0; i < h; i++)
 	{
-		*dstPtr  = pixVal;
+		*dstPtr = pixVal;
 		 dstPtr += SCREEN_W;
 	}
 }
@@ -935,13 +1008,13 @@ void drawFramework(uint16_t x, uint16_t y, uint16_t w, uint16_t h, uint8_t type)
 
 void showTopLeftMainScreen(bool restoreScreens)
 {
-	editor.ui.diskOpShown          = false;
+	editor.ui.diskOpShown = false;
 	editor.ui.sampleEditorExtShown = false;
-	editor.ui.instEditorExtShown   = false;
-	editor.ui.transposeShown       = false;
-	editor.ui.advEditShown         = false;
-	editor.ui.wavRendererShown     = false;
-	editor.ui.trimScreenShown      = false;
+	editor.ui.instEditorExtShown = false;
+	editor.ui.transposeShown = false;
+	editor.ui.advEditShown = false;
+	editor.ui.wavRendererShown = false;
+	editor.ui.trimScreenShown = false;
 
 	editor.ui.scopesShown = true;
 	if (restoreScreens)
@@ -949,13 +1022,13 @@ void showTopLeftMainScreen(bool restoreScreens)
 		switch (editor.ui.oldTopLeftScreen)
 		{
 			default: break;
-			case 1: editor.ui.diskOpShown          = true; break;
+			case 1: editor.ui.diskOpShown = true; break;
 			case 2: editor.ui.sampleEditorExtShown = true; break;
-			case 3: editor.ui.instEditorExtShown   = true; break;
-			case 4: editor.ui.transposeShown       = true; break;
-			case 5: editor.ui.advEditShown         = true; break;
-			case 6: editor.ui.wavRendererShown     = true; break;
-			case 7: editor.ui.trimScreenShown      = true; break;
+			case 3: editor.ui.instEditorExtShown = true; break;
+			case 4: editor.ui.transposeShown = true; break;
+			case 5: editor.ui.advEditShown = true; break;
+			case 6: editor.ui.wavRendererShown = true; break;
+			case 7: editor.ui.trimScreenShown = true; break;
 		}
 
 		if (editor.ui.oldTopLeftScreen > 0)
@@ -1205,10 +1278,22 @@ void showTopScreen(bool restoreScreens)
 {
 	editor.ui.scopesShown = false;
 
-	     if (editor.ui.aboutScreenShown)  showAboutScreen();
-	else if (editor.ui.configScreenShown) showConfigScreen();
-	else if (editor.ui.helpScreenShown)   showHelpScreen();
-	else if (editor.ui.nibblesShown)      showNibblesScreen();
+	if (editor.ui.aboutScreenShown)
+	{
+		showAboutScreen();
+	}
+	else if (editor.ui.configScreenShown)
+	{
+		showConfigScreen();
+	}
+	else if (editor.ui.helpScreenShown)
+	{
+		showHelpScreen();
+	}
+	else if (editor.ui.nibblesShown)
+	{
+		showNibblesScreen();
+	}
 	else
 	{
 		showTopLeftMainScreen(restoreScreens); // updates editor.ui.scopesShown
