@@ -6,6 +6,7 @@
 #include <stdio.h>
 #include <stdint.h>
 #include <stdbool.h>
+#include <math.h>
 #include "ft2_header.h"
 #include "ft2_config.h"
 #include "ft2_audio.h"
@@ -18,6 +19,7 @@
 #include "ft2_video.h"
 #include "ft2_sample_loader.h"
 #include "ft2_diskop.h"
+#include "ft2_module_loader.h"
 
 #ifdef _MSC_VER
 #pragma pack(push)
@@ -71,7 +73,7 @@ typedef struct instrXIHeaderTyp_t
 	uint8_t ta[96];
 	int16_t envVP[12][2], envPP[12][2];
 	uint8_t envVPAnt, envPPAnt, envVSust, envVRepS, envVRepE, envPSust, envPRepS;
-	uint8_t envPRepE, envVtyp, envPtyp, vibTyp, vibSweep, vibDepth, vibRate;
+	uint8_t envPRepE, envVTyp, envPTyp, vibTyp, vibSweep, vibDepth, vibRate;
 	uint16_t fadeOut;
 	uint8_t midiOn, midiChannel;
 	int16_t midiProgram, midiBend;
@@ -2004,7 +2006,7 @@ static void writeEnvelope(int32_t nr)
 			le = -1;
 		}
 
-		curEnvP  = ins->envVP;
+		curEnvP = ins->envVP;
 		selected = editor.currVolEnvPoint;
 	}
 	else
@@ -2026,7 +2028,7 @@ static void writeEnvelope(int32_t nr)
 			le = -1;
 		}
 
-		curEnvP  = ins->envPP;
+		curEnvP = ins->envPP;
 		selected = editor.currPanEnvPoint;
 	}
 
@@ -2933,11 +2935,13 @@ bool testInstrSwitcherMouseDown(void)
 static int32_t SDLCALL saveInstrThread(void *ptr)
 {
 	int16_t n;
+	int32_t i;
 	size_t result;
 	FILE *f;
 	instrXIHeaderTyp ih;
-	sampleTyp *srcSmp;
-	sampleHeaderTyp *dstSmpHdr;
+	instrTyp *ins;
+	sampleTyp *s;
+	sampleHeaderTyp *dst;
 
 	(void)ptr;
 
@@ -2948,7 +2952,7 @@ static int32_t SDLCALL saveInstrThread(void *ptr)
 	}
 
 	n = getUsedSamples(saveInstrNr);
-	if (n == 0)
+	if (n == 0 || instr[saveInstrNr] == NULL)
 	{
 		okBoxThreadSafe(0, "System message", "Instrument is empty!");
 		return false;
@@ -2961,7 +2965,8 @@ static int32_t SDLCALL saveInstrThread(void *ptr)
 		return false;
 	}
 
-	memset(&ih, 0, sizeof (ih));
+	memset(&ih, 0, sizeof (ih)); // important, also clears reserved stuff
+
 	memcpy(ih.sig, "Extended Instrument: ", 21);
 	memset(ih.name, ' ', 22);
 	memcpy(ih.name, song.instrName[saveInstrNr], strlen(song.instrName[saveInstrNr]));
@@ -2969,17 +2974,53 @@ static int32_t SDLCALL saveInstrThread(void *ptr)
 	memcpy(ih.progName, PROG_NAME_STR, 20);
 	ih.ver = 0x0102;
 
-	memcpy(ih.ta, &instr[saveInstrNr], INSTR_SIZE);
+	// copy over instrument struct data to instrument header
+	ins = instr[saveInstrNr];
+	memcpy(ih.ta, ins->ta, 96);
+	memcpy(ih.envVP, ins->envVP, 12*2*sizeof(int16_t));
+	memcpy(ih.envPP, ins->envPP, 12*2*sizeof(int16_t));
+	ih.envVPAnt = ins->envVPAnt;
+	ih.envPPAnt = ins->envPPAnt;
+	ih.envVSust = ins->envVSust;
+	ih.envVRepS = ins->envVRepS;
+	ih.envVRepE = ins->envVRepE;
+	ih.envPSust = ins->envPSust;
+	ih.envPRepS = ins->envPRepS;
+	ih.envPRepE = ins->envPRepE;
+	ih.envVTyp = ins->envVTyp;
+	ih.envPTyp = ins->envPTyp;
+	ih.vibTyp = ins->vibTyp;
+	ih.vibSweep = ins->vibSweep;
+	ih.vibDepth = ins->vibDepth;
+	ih.vibRate = ins->vibRate;
+	ih.fadeOut = ins->fadeOut;
+	ih.midiOn = ins->midiOn ? 1 : 0;
+	ih.midiChannel = ins->midiChannel;
+	ih.midiProgram = ins->midiProgram;
+	ih.midiBend = ins->midiBend;
+	ih.mute = ins->mute ? 1 : 0;
 	ih.antSamp = n;
 
-	for (int16_t i = 0; i < n; i++)
+	// copy over sample struct datas to sample headers
+	for (i = 0; i < n; i++)
 	{
-		srcSmp = &instr[saveInstrNr]->samp[i];
-		dstSmpHdr = &ih.samp[i];
+		s = &instr[saveInstrNr]->samp[i];
+		dst = &ih.samp[i];
 
-		memcpy(&dstSmpHdr->len, &srcSmp->len, 12+4+2 + strlen(srcSmp->name));
-		if (srcSmp->pek == NULL)
-			dstSmpHdr->len = 0;
+		dst->len = s->len;
+		dst->repS = s->repS;
+		dst->repL = s->repL;
+		dst->vol = s->vol;
+		dst->fine = s->fine;
+		dst->typ = s->typ;
+		dst->pan = s->pan;
+		dst->relTon = s->relTon;
+
+		dst->nameLen = (uint8_t)strlen(s->name);
+		memcpy(dst->name, s->name, 22);
+
+		if (s->pek == NULL)
+			dst->len = 0;
 	}
 
 	result = fwrite(&ih, INSTR_XI_HEADER_SIZE + (ih.antSamp * sizeof (sampleHeaderTyp)), 1, f);
@@ -2991,20 +3032,20 @@ static int32_t SDLCALL saveInstrThread(void *ptr)
 	}
 
 	pauseAudio();
-	for (int16_t i = 0; i < n; i++)
+	for (i = 0; i < n; i++)
 	{
-		srcSmp = &instr[saveInstrNr]->samp[i];
-		if (srcSmp->pek != NULL)
+		s = &instr[saveInstrNr]->samp[i];
+		if (s->pek != NULL && s->len > 0)
 		{
-			restoreSample(srcSmp);
-			samp2Delta(srcSmp->pek, srcSmp->len, srcSmp->typ);
+			restoreSample(s);
+			samp2Delta(s->pek, s->len, s->typ);
 
-			result = fwrite(srcSmp->pek, 1, srcSmp->len, f);
+			result = fwrite(s->pek, 1, s->len, f);
 
-			delta2Samp(srcSmp->pek, srcSmp->len, srcSmp->typ);
-			fixSample(srcSmp);
+			delta2Samp(s->pek, s->len, s->typ);
+			fixSample(s);
 
-			if (result != (size_t)srcSmp->len) // write not OK
+			if (result != (size_t)s->len) // write not OK
 			{
 				resumeAudio();
 				fclose(f);
@@ -3044,10 +3085,7 @@ void saveInstr(UNICHAR *filenameU, int16_t nr)
 
 static int16_t getPATNote(int32_t freq)
 {
-	double dFreq;
-
-	dFreq = ((log(freq / (440.0 * 1000.0)) / M_LN2) * 12.0) + 48.0 + 9.0;
-	return (int16_t)round(dFreq);
+	return (int16_t)round(((log(freq / (440.0 * 1000.0)) / M_LN2) * 12.0) + 48.0 + 9.0);
 }
 
 static int32_t SDLCALL loadInstrThread(void *ptr)
@@ -3055,11 +3093,13 @@ static int32_t SDLCALL loadInstrThread(void *ptr)
 	bool stereoWarning;
 	int8_t *newPtr;
 	int16_t a, b;
+	int32_t i, j;
 	double dFreq;
 	FILE *f;
 	instrXIHeaderTyp ih;
 	instrPATHeaderTyp ih_PAT;
 	instrPATWaveHeaderTyp ih_PATWave;
+	sampleHeaderTyp *src;
 	sampleTyp *s;
 	instrTyp *ins;
 
@@ -3093,14 +3133,16 @@ static int32_t SDLCALL loadInstrThread(void *ptr)
 			goto loadDone;
 		}
 
-		if (ih.ver == 0x0101)
+		if (ih.ver == 0x0101) // not even FT2.01 can save old v1.01 .XI files, so I have no way to verify this.
 		{
-			fseek(f, -2 - 15 - 1 - 2, SEEK_CUR);
+			fseek(f, -20, SEEK_CUR);
 			ih.antSamp = ih.midiProgram;
-			memset(&ih.midiProgram, 0, 2+15+1+2);
+			ih.midiProgram = 0;
+			ih.midiBend = 0;
+			ih.mute = false;
 		}
 
-		if (ih.antSamp > 16)
+		if (ih.antSamp > MAX_SMP_PER_INST)
 		{
 			okBoxThreadSafe(0, "System message", "Incompatible instrument!");
 			goto loadDone;
@@ -3122,44 +3164,67 @@ static int32_t SDLCALL loadInstrThread(void *ptr)
 				goto loadDone;
 			}
 
+			// copy instrument header elements to our instrument struct
+
+			ins = instr[editor.curInstr];
+			memcpy(ins->ta, ih.ta, 96);
+			memcpy(ins->envVP, ih.envVP, 12*2*sizeof(int16_t));
+			memcpy(ins->envPP, ih.envPP, 12*2*sizeof(int16_t));
+			ins->envVPAnt = ih.envVPAnt;
+			ins->envPPAnt = ih.envPPAnt;
+			ins->envVSust = ih.envVSust;
+			ins->envVRepS = ih.envVRepS;
+			ins->envVRepE = ih.envVRepE;
+			ins->envPSust = ih.envPSust;
+			ins->envPRepS = ih.envPRepS;
+			ins->envPRepE = ih.envPRepE;
+			ins->envVTyp = ih.envVTyp;
+			ins->envPTyp = ih.envPTyp;
+			ins->vibTyp = ih.vibTyp;
+			ins->vibSweep = ih.vibSweep;
+			ins->vibDepth = ih.vibDepth;
+			ins->vibRate = ih.vibRate;
+			ins->fadeOut = ih.fadeOut;
+			ins->midiOn = (ih.midiOn > 0) ? true : false;
+			ins->midiChannel = ih.midiChannel;
+			ins->midiProgram = ih.midiProgram;
+			ins->midiBend = ih.midiBend;
+			ins->mute = (ih.mute > 0) ? true : false;
+			ins->antSamp = ih.antSamp; // used in loadInstrSample()
+
 			// sanitize stuff for broken/unsupported instruments
-			ih.midiProgram = CLAMP(ih.midiProgram, 0, 127);
-			ih.midiBend = CLAMP(ih.midiBend, 0, 36);
+			ins->midiProgram = CLAMP(ins->midiProgram, 0, 127);
+			ins->midiBend = CLAMP(ins->midiBend, 0, 36);
 
-			if (ih.midiChannel > 15) ih.midiChannel = 15;
-			if (ih.mute != 1) ih.mute = 0;
-			if (ih.midiOn!= 1) ih.midiOn = 0;
-			if (ih.vibDepth > 0x0F) ih.vibDepth = 0x0F;
-			if (ih.vibRate > 0x3F) ih.vibRate = 0x3F;
-			if (ih.vibTyp > 3) ih.vibTyp = 0;
+			if (ins->midiChannel > 15) ins->midiChannel = 15;
+			if (ins->vibDepth > 0x0F) ins->vibDepth = 0x0F;
+			if (ins->vibRate > 0x3F) ins->vibRate = 0x3F;
+			if (ins->vibTyp > 3) ins->vibTyp = 0;
 
-			for (int16_t i = 0; i < 96; i++)
+			for (i = 0; i < 96; i++)
 			{
-				if (ih.ta[i] > 15)
-					ih.ta[i] = 15;
+				if (ins->ta[i] > 15)
+					ins->ta[i] = 15;
 			}
 
-			if (ih.envVPAnt > 12) ih.envVPAnt = 12;
-			if (ih.envVRepS > 11) ih.envVRepS = 11;
-			if (ih.envVRepE > 11) ih.envVRepE = 11;
-			if (ih.envVSust > 11) ih.envVSust = 11;
-			if (ih.envPPAnt > 12) ih.envPPAnt = 12;
-			if (ih.envPRepS > 11) ih.envPRepS = 11;
-			if (ih.envPRepE > 11) ih.envPRepE = 11;
-			if (ih.envPSust > 11) ih.envPSust = 11;
+			if (ins->envVPAnt > 12) ins->envVPAnt = 12;
+			if (ins->envVRepS > 11) ins->envVRepS = 11;
+			if (ins->envVRepE > 11) ins->envVRepE = 11;
+			if (ins->envVSust > 11) ins->envVSust = 11;
+			if (ins->envPPAnt > 12) ins->envPPAnt = 12;
+			if (ins->envPRepS > 11) ins->envPRepS = 11;
+			if (ins->envPRepE > 11) ins->envPRepE = 11;
+			if (ins->envPSust > 11) ins->envPSust = 11;
 
-			for (int16_t i = 0; i < 12; i++)
+			for (i = 0; i < 12; i++)
 			{
-				if ((uint16_t)ih.envVP[i][0] > 32767) ih.envVP[i][0] = 32767;
-				if ((uint16_t)ih.envPP[i][0] > 32767) ih.envPP[i][0] = 32767;
-				if ((uint16_t)ih.envVP[i][1] > 64) ih.envVP[i][1] = 64;
-				if ((uint16_t)ih.envPP[i][1] > 63) ih.envPP[i][1] = 63;
+				if ((uint16_t)ins->envVP[i][0] > 32767) ins->envVP[i][0] = 32767;
+				if ((uint16_t)ins->envPP[i][0] > 32767) ins->envPP[i][0] = 32767;
+				if ((uint16_t)ins->envVP[i][1] > 64) ins->envVP[i][1] = 64;
+				if ((uint16_t)ins->envPP[i][1] > 63) ins->envPP[i][1] = 63;
+				
 			}
 
-			// ----------------------------------------
-
-			memcpy(instr[editor.curInstr]->ta, ih.ta, INSTR_SIZE);
-
 			if (fread(ih.samp, sizeof (sampleHeaderTyp) * ih.antSamp, 1, f) != 1)
 			{
 				freeInstr(editor.curInstr);
@@ -3168,23 +3233,50 @@ static int32_t SDLCALL loadInstrThread(void *ptr)
 				goto loadDone;
 			}
 
-			for (int16_t i = 0; i < ih.antSamp; i++)
-				memcpy(&instr[editor.curInstr]->samp[i], &ih.samp[i], 12 + 4 + 24);
+			for (i = 0; i < ih.antSamp; i++)
+			{
+				s = &instr[editor.curInstr]->samp[i];
+				src = &ih.samp[i];
+
+				// copy sample header elements to our sample struct
+
+				s->len = src->len;
+				s->repS = src->repS;
+				s->repL = src->repL;
+				s->vol = src->vol;
+				s->fine = src->fine;
+				s->typ = src->typ;
+				s->pan = src->pan;
+				s->relTon = src->relTon;
+				memcpy(s->name, src->name, 22);
+				s->name[22] = '\0';
+
+				// dst->pek is set up later
+
+				// trim off spaces at end of name
+				for (j = 21; j >= 0; j--)
+				{
+					if (s->name[j] == ' ' || s->name[j] == 0x1A)
+						s->name[j] = '\0';
+					else
+						break;
+				}
+
+				// sanitize stuff broken/unsupported samples
+				if (s->vol > 64)
+					s->vol = 64;
+
+				s->relTon = CLAMP(s->relTon, -48, 71);
+			}
 		}
 
-		for (int16_t i = 0; i < ih.antSamp; i++)
+		for (i = 0; i < ih.antSamp; i++)
 		{
 			s = &instr[editor.curInstr]->samp[i];
 
-			// sanitize stuff for malicious modules
-			if (s->vol > 64)
-				s->vol = 64;
-
-			s->relTon = CLAMP(s->relTon, -48, 71);
-
-			// if a sample has both forward loop and pingpong loop set, make it pingpong loop only (FT2 behavior)
+			// if a sample has both forward loop and pingpong loop set, make it pingpong loop only (FT2 mixer behavior)
 			if ((s->typ & 3) == 3)
-				s->typ = 2;
+				s->typ &= 0xFE;
 
 			if (s->len > 0)
 			{
@@ -3223,6 +3315,7 @@ static int32_t SDLCALL loadInstrThread(void *ptr)
 					stereoWarning = true;
 				}
 
+				checkSampleRepeat(s);
 				fixSample(s);
 			}
 		}
@@ -3256,7 +3349,7 @@ static int32_t SDLCALL loadInstrThread(void *ptr)
 			memset(song.instrName[editor.curInstr], 0, 22 + 1);
 			memcpy(song.instrName[editor.curInstr], ih_PAT.instrName, 16);
 
-			for (int16_t i = 0; i < ih_PAT.antSamp; i++)
+			for (i = 0; i < ih_PAT.antSamp; i++)
 			{
 				s = &instr[editor.curInstr]->samp[i];
 				ins = instr[editor.curInstr];
@@ -3281,8 +3374,14 @@ static int32_t SDLCALL loadInstrThread(void *ptr)
 				if (i == 0)
 				{
 					ins->vibSweep = ih_PATWave.vibSweep;
-					ins->vibRate  = ih_PATWave.vibRate  / 2; if (ins->vibRate  > 0x3F) ins->vibRate  = 0x3F;
-					ins->vibDepth = ih_PATWave.vibDepth / 2; if (ins->vibDepth > 0x0F) ins->vibDepth = 0x0F;
+
+					ins->vibRate = ih_PATWave.vibRate / 2;
+					if (ins->vibRate > 0x3F)
+						ins->vibRate = 0x3F;
+
+					ins->vibDepth = ih_PATWave.vibDepth / 2;
+					if (ins->vibDepth > 0x0F)
+						ins->vibDepth = 0x0F;
 				}
 
 				s = &instr[editor.curInstr]->samp[i];
@@ -3298,7 +3397,7 @@ static int32_t SDLCALL loadInstrThread(void *ptr)
 						s->typ |= 1; // forward loop
 				}
 
-				s->pan = (ih_PATWave.pan == 8) ? 128 : (ih_PATWave.pan * 17); // FT2 does <<4 here, I don't like that!
+				s->pan = ih_PATWave.pan << 4;
 				s->len = ih_PATWave.waveSize;
 
 				s->repS = ih_PATWave.repS;
@@ -3323,13 +3422,16 @@ static int32_t SDLCALL loadInstrThread(void *ptr)
 				dFreq = round((1.0 + ih_PATWave.fineTune / 512.0) * ih_PATWave.sampleRate);
 				tuneSample(s, (int32_t)dFreq);
 
-				s->relTon -= (int8_t)(getPATNote(ih_PATWave.rootFrq) - (12 * 3));
-				s->relTon  = CLAMP(s->relTon, -48, 71);
+				s->relTon -= (int8_t)(getPATNote(ih_PATWave.rootFrq) - (12*3));
+				s->relTon = CLAMP(s->relTon, -48, 71);
 
-				a = getPATNote(ih_PATWave.lowFrq);   a = CLAMP(a, 0, 95);
-				b = getPATNote(ih_PATWave.highFreq); b = CLAMP(b, 0, 95);
+				a = getPATNote(ih_PATWave.lowFrq);
+				a = CLAMP(a, 0, 95);
 
-				for (int16_t j = a; j <= b; j++)
+				b = getPATNote(ih_PATWave.highFreq);
+				b = CLAMP(b, 0, 95);
+
+				for (j = a; j <= b; j++)
 					ins->ta[j] = (uint8_t)i;
 
 				if (fread(s->pek, ih_PATWave.waveSize, 1, f) != 1)
