@@ -560,18 +560,18 @@ static void drawRowNums(int32_t yPos, uint8_t row, bool selectedRowFlag)
 
 	for (uint32_t y = 0; y < FONT4_CHAR_H; y++)
 	{
-		for (uint32_t x1 = 0; x1 < FONT4_CHAR_W; x1++)
+		for (uint32_t x = 0; x < FONT4_CHAR_W; x++)
 		{
-			if (src1Ptr[x1])
+			if (src1Ptr[x])
 			{
-				dst1Ptr[x1] = pixVal; // left side
-				dst2Ptr[x1] = pixVal; // right side
+				dst1Ptr[x] = pixVal; // left side
+				dst2Ptr[x] = pixVal; // right side
 			}
 
-			if (src2Ptr[x1])
+			if (src2Ptr[x])
 			{
-				dst1Ptr[FONT4_CHAR_W + x1] = pixVal; // left side
-				dst2Ptr[FONT4_CHAR_W + x1] = pixVal; // right side
+				dst1Ptr[FONT4_CHAR_W+x] = pixVal; // left side
+				dst2Ptr[FONT4_CHAR_W+x] = pixVal; // right side
 			}
 		}
 
@@ -898,6 +898,7 @@ void writePattern(int32_t currRow, int32_t pattern)
 	noteTextColors[0] = video.palette[PAL_PATTEXT]; // not selected
 	noteTextColors[1] = video.palette[PAL_FORGRND]; // selected
 
+	// increment pattern data pointer by horizontal scrollbar offset/channel
 	if (pattPtr != NULL)
 		pattPtr += editor.ui.channelOffset;
 
@@ -977,6 +978,9 @@ void pattTwoHexOut(uint32_t xPos, uint32_t yPos, uint8_t val, uint32_t color)
 {
 	const uint8_t *ch1Ptr, *ch2Ptr;
 	uint32_t *dstPtr;
+#ifndef __arm__
+	uint32_t tmp;
+#endif
 
 	ch1Ptr = &font4Ptr[(val   >> 4) * FONT4_CHAR_W];
 	ch2Ptr = &font4Ptr[(val & 0x0F) * FONT4_CHAR_W];
@@ -986,8 +990,19 @@ void pattTwoHexOut(uint32_t xPos, uint32_t yPos, uint8_t val, uint32_t color)
 	{
 		for (uint32_t x = 0; x < FONT4_CHAR_W; x++)
 		{
-			if (ch1Ptr[x]) dstPtr[x] = color;
-			if (ch2Ptr[x]) dstPtr[FONT4_CHAR_W + x] = color;
+#ifdef __arm__
+			if (ch1Ptr[x] != 0) dstPtr[x] = color;
+			if (ch2Ptr[x] != 0) dstPtr[FONT4_CHAR_W+x] = color;
+#else
+			// carefully written like this to generate conditional move instructions (font data is hard to predict)
+			tmp = dstPtr[x];
+			if (ch1Ptr[x] != 0) tmp = color;
+			dstPtr[x] = tmp;
+
+			tmp = dstPtr[FONT4_CHAR_W+x];
+			if (ch2Ptr[x] != 0) tmp = color;
+			dstPtr[FONT4_CHAR_W+x] = tmp;
+#endif
 		}
 
 		ch1Ptr += FONT4_WIDTH;
@@ -1000,6 +1015,9 @@ static void pattCharOut(uint32_t xPos, uint32_t yPos, uint8_t chr, uint8_t fontT
 {
 	const uint8_t *srcPtr;
 	uint32_t x, y, *dstPtr;
+#ifndef __arm__
+	uint32_t tmp;
+#endif
 
 	dstPtr = &video.frameBuffer[(yPos * SCREEN_W) + xPos];
 
@@ -1010,8 +1028,15 @@ static void pattCharOut(uint32_t xPos, uint32_t yPos, uint8_t chr, uint8_t fontT
 		{
 			for (x = 0; x < FONT3_CHAR_W; x++)
 			{
-				if (srcPtr[x])
+#ifdef __arm__
+				if (srcPtr[x] != 0)
 					dstPtr[x] = color;
+#else
+				// carefully written like this to generate conditional move instructions (font data is hard to predict)
+				tmp = dstPtr[x];
+				if (srcPtr[x] != 0) tmp = color;
+				dstPtr[x] = tmp;
+#endif
 			}
 
 			srcPtr += FONT3_WIDTH;
@@ -1025,8 +1050,15 @@ static void pattCharOut(uint32_t xPos, uint32_t yPos, uint8_t chr, uint8_t fontT
 		{
 			for (x = 0; x < FONT4_CHAR_W; x++)
 			{
-				if (srcPtr[x])
+#ifdef __arm__
+				if (srcPtr[x] != 0)
 					dstPtr[x] = color;
+#else
+				// carefully written like this to generate conditional move instructions (font data is hard to predict)
+				tmp = dstPtr[x];
+				if (srcPtr[x] != 0) tmp = color;
+				dstPtr[x] = tmp;
+#endif
 			}
 
 			srcPtr += FONT4_WIDTH;
@@ -1040,8 +1072,15 @@ static void pattCharOut(uint32_t xPos, uint32_t yPos, uint8_t chr, uint8_t fontT
 		{
 			for (x = 0; x < FONT5_CHAR_W; x++)
 			{
-				if (srcPtr[x])
+#ifdef __arm__
+				if (srcPtr[x] != 0)
 					dstPtr[x] = color;
+#else
+				// carefully written like this to generate conditional move instructions (font data is hard to predict)
+				tmp = dstPtr[x];
+				if (srcPtr[x] != 0) tmp = color;
+				dstPtr[x] = tmp;
+#endif
 			}
 
 			srcPtr += FONT5_WIDTH;
@@ -1055,8 +1094,15 @@ static void pattCharOut(uint32_t xPos, uint32_t yPos, uint8_t chr, uint8_t fontT
 		{
 			for (x = 0; x < FONT7_CHAR_W; x++)
 			{
-				if (srcPtr[x])
+#ifdef __arm__
+				if (srcPtr[x] != 0)
 					dstPtr[x] = color;
+#else
+				// carefully written like this to generate conditional move instructions (font data is hard to predict)
+				tmp = dstPtr[x];
+				if (srcPtr[x] != 0) tmp = color;
+				dstPtr[x] = tmp;
+#endif
 			}
 
 			srcPtr += FONT7_WIDTH;
@@ -1069,6 +1115,9 @@ static void drawEmptyNoteSmall(uint32_t xPos, uint32_t yPos, uint32_t color)
 {
 	const uint8_t *srcPtr;
 	uint32_t *dstPtr;
+#ifndef __arm__
+	uint32_t tmp;
+#endif
 
 	srcPtr = &font7Data[18 * FONT7_CHAR_W];
 	dstPtr = &video.frameBuffer[(yPos * SCREEN_W) + xPos];
@@ -1077,8 +1126,15 @@ static void drawEmptyNoteSmall(uint32_t xPos, uint32_t yPos, uint32_t color)
 	{
 		for (uint32_t x = 0; x < FONT7_CHAR_W*3; x++)
 		{
-			if (srcPtr[x])
+#ifdef __arm__
+			if (srcPtr[x] != 0)
 				dstPtr[x] = color;
+#else
+			// carefully written like this to generate conditional move instructions (font data is hard to predict)
+			tmp = dstPtr[x];
+			if (srcPtr[x] != 0) tmp = color;
+			dstPtr[x] = tmp;
+#endif
 		}
 
 		srcPtr += FONT7_WIDTH;
@@ -1090,6 +1146,9 @@ static void drawKeyOffSmall(uint32_t xPos, uint32_t yPos, uint32_t color)
 {
 	const uint8_t *srcPtr;
 	uint32_t *dstPtr;
+#ifndef __arm__
+	uint32_t tmp;
+#endif
 
 	srcPtr = &font7Data[21 * FONT7_CHAR_W];
 	dstPtr = &video.frameBuffer[(yPos * SCREEN_W) + (xPos + 2)];
@@ -1098,8 +1157,15 @@ static void drawKeyOffSmall(uint32_t xPos, uint32_t yPos, uint32_t color)
 	{
 		for (uint32_t x = 0; x < FONT7_CHAR_W*2; x++)
 		{
-			if (srcPtr[x])
+#ifdef __arm__
+			if (srcPtr[x] != 0)
 				dstPtr[x] = color;
+#else
+			// carefully written like this to generate conditional move instructions (font data is hard to predict)
+			tmp = dstPtr[x];
+			if (srcPtr[x] != 0) tmp = color;
+			dstPtr[x] = tmp;
+#endif
 		}
 
 		srcPtr += FONT7_WIDTH;
@@ -1112,6 +1178,9 @@ static void drawNoteSmall(uint32_t xPos, uint32_t yPos, int32_t ton, uint32_t co
 	const uint8_t *ch1Ptr, *ch2Ptr, *ch3Ptr;
 	uint8_t note;
 	uint32_t *dstPtr, char1, char2, char3;
+#ifndef __arm__
+	uint32_t tmp;
+#endif
 
 	assert(ton >= 1 && ton <= 97);
 
@@ -1140,9 +1209,24 @@ static void drawNoteSmall(uint32_t xPos, uint32_t yPos, int32_t ton, uint32_t co
 	{
 		for (uint32_t x = 0; x < FONT7_CHAR_W; x++)
 		{
-			if (ch1Ptr[x]) dstPtr[ (FONT7_CHAR_W * 0)      + x] = color;
-			if (ch2Ptr[x]) dstPtr[ (FONT7_CHAR_W * 1)      + x] = color;
-			if (ch3Ptr[x]) dstPtr[((FONT7_CHAR_W * 2) - 2) + x] = color;
+#ifdef __arm__
+			if (ch1Ptr[x] != 0) dstPtr[x] = color;
+			if (ch2Ptr[x] != 0) dstPtr[FONT7_CHAR_W+x] = color;
+			if (ch3Ptr[x] != 0) dstPtr[((FONT7_CHAR_W*2)-2)+x] = color;
+#else
+			// carefully written like this to generate conditional move instructions (font data is hard to predict)
+			tmp = dstPtr[x];
+			if (ch1Ptr[x] != 0) tmp = color;
+			dstPtr[x] = tmp;
+
+			tmp = dstPtr[FONT7_CHAR_W+x];
+			if (ch2Ptr[x] != 0) tmp = color;
+			dstPtr[FONT7_CHAR_W+x] = tmp;
+
+			tmp = dstPtr[((FONT7_CHAR_W*2)-2)+x]; // -2 to get correct alignment for ending glyph
+			if (ch3Ptr[x] != 0) tmp = color;
+			dstPtr[((FONT7_CHAR_W*2)-2)+x] = tmp;
+#endif
 		}
 
 		ch1Ptr += FONT7_WIDTH;
@@ -1156,6 +1240,9 @@ static void drawEmptyNoteMedium(uint32_t xPos, uint32_t yPos, uint32_t color)
 {
 	const uint8_t *srcPtr;
 	uint32_t *dstPtr;
+#ifndef __arm__
+	uint32_t tmp;
+#endif
 
 	dstPtr = &video.frameBuffer[(yPos * SCREEN_W) + xPos];
 	srcPtr = &font4Ptr[43 * FONT4_CHAR_W];
@@ -1164,8 +1251,15 @@ static void drawEmptyNoteMedium(uint32_t xPos, uint32_t yPos, uint32_t color)
 	{
 		for (uint32_t x = 0; x < FONT4_CHAR_W*3; x++)
 		{
-			if (srcPtr[x])
+#ifdef __arm__
+			if (srcPtr[x] != 0)
 				dstPtr[x] = color;
+#else
+			// carefully written like this to generate conditional move instructions (font data is hard to predict)
+			tmp = dstPtr[x];
+			if (srcPtr[x] != 0) tmp = color;
+			dstPtr[x] = tmp;
+#endif
 		}
 
 		srcPtr += FONT4_WIDTH;
@@ -1177,6 +1271,9 @@ static void drawKeyOffMedium(uint32_t xPos, uint32_t yPos, uint32_t color)
 {
 	const uint8_t *srcPtr;
 	uint32_t *dstPtr;
+#ifndef __arm__
+	uint32_t tmp;
+#endif
 
 	srcPtr = &font4Ptr[40 * FONT4_CHAR_W];
 	dstPtr = &video.frameBuffer[(yPos * SCREEN_W) + xPos];
@@ -1185,8 +1282,15 @@ static void drawKeyOffMedium(uint32_t xPos, uint32_t yPos, uint32_t color)
 	{
 		for (uint32_t x = 0; x < FONT4_CHAR_W*3; x++)
 		{
-			if (srcPtr[x])
+#ifdef __arm__
+			if (srcPtr[x] != 0)
 				dstPtr[x] = color;
+#else
+			// carefully written like this to generate conditional move instructions (font data is hard to predict)
+			tmp = dstPtr[x];
+			if (srcPtr[x] != 0) tmp = color;
+			dstPtr[x] = tmp;
+#endif
 		}
 
 		srcPtr += FONT4_WIDTH;
@@ -1198,6 +1302,9 @@ static void drawNoteMedium(uint32_t xPos, uint32_t yPos, int32_t ton, uint32_t c
 {
 	const uint8_t *ch1Ptr, *ch2Ptr, *ch3Ptr;
 	uint32_t note, *dstPtr, char1, char2, char3;
+#ifndef __arm__
+	uint32_t tmp;
+#endif
 
 	ton--;
 
@@ -1224,9 +1331,24 @@ static void drawNoteMedium(uint32_t xPos, uint32_t yPos, int32_t ton, uint32_t c
 	{
 		for (uint32_t x = 0; x < FONT4_CHAR_W; x++)
 		{
-			if (ch1Ptr[x]) dstPtr[(FONT4_CHAR_W * 0) + x] = color;
-			if (ch2Ptr[x]) dstPtr[(FONT4_CHAR_W * 1) + x] = color;
-			if (ch3Ptr[x]) dstPtr[(FONT4_CHAR_W * 2) + x] = color;
+#ifdef __arm__
+			if (ch1Ptr[x] != 0) dstPtr[x] = color;
+			if (ch2Ptr[x] != 0) dstPtr[FONT4_CHAR_W+x] = color;
+			if (ch3Ptr[x] != 0) dstPtr[(FONT4_CHAR_W*2)+x] = color;
+#else
+			// carefully written like this to generate conditional move instructions (font data is hard to predict)
+			tmp = dstPtr[x];
+			if (ch1Ptr[x] != 0) tmp = color;
+			dstPtr[x] = tmp;
+
+			tmp = dstPtr[FONT4_CHAR_W+x];
+			if (ch2Ptr[x] != 0) tmp = color;
+			dstPtr[FONT4_CHAR_W+x] = tmp;
+
+			tmp = dstPtr[(FONT4_CHAR_W*2)+x];
+			if (ch3Ptr[x] != 0) tmp = color;
+			dstPtr[(FONT4_CHAR_W*2)+x] = tmp;
+#endif
 		}
 
 		ch1Ptr += FONT4_WIDTH;
@@ -1240,6 +1362,9 @@ static void drawEmptyNoteBig(uint32_t xPos, uint32_t yPos, uint32_t color)
 {
 	const uint8_t *srcPtr;
 	uint32_t *dstPtr;
+#ifndef __arm__
+	uint32_t tmp;
+#endif
 
 	srcPtr = &font4Ptr[67 * FONT4_CHAR_W];
 	dstPtr = &video.frameBuffer[(yPos * SCREEN_W) + xPos];
@@ -1248,8 +1373,15 @@ static void drawEmptyNoteBig(uint32_t xPos, uint32_t yPos, uint32_t color)
 	{
 		for (uint32_t x = 0; x < FONT4_CHAR_W*6; x++)
 		{
-			if (srcPtr[x])
+#ifdef __arm__
+			if (srcPtr[x] != 0)
 				dstPtr[x] = color;
+#else
+			// carefully written like this to generate conditional move instructions (font data is hard to predict)
+			tmp = dstPtr[x];
+			if (srcPtr[x] != 0) tmp = color;
+			dstPtr[x] = tmp;
+#endif
 		}
 
 		srcPtr += FONT4_WIDTH;
@@ -1261,6 +1393,9 @@ static void drawKeyOffBig(uint32_t xPos, uint32_t yPos, uint32_t color)
 {
 	const uint8_t *srcPtr;
 	uint32_t *dstPtr;
+#ifndef __arm__
+	uint32_t tmp;
+#endif
 
 	srcPtr = &font4Data[61 * FONT4_CHAR_W];
 	dstPtr = &video.frameBuffer[(yPos * SCREEN_W) + xPos];
@@ -1269,8 +1404,15 @@ static void drawKeyOffBig(uint32_t xPos, uint32_t yPos, uint32_t color)
 	{
 		for (uint32_t x = 0; x < FONT4_CHAR_W*6; x++)
 		{
-			if (srcPtr[x])
+#ifdef __arm__
+			if (srcPtr[x] != 0)
 				dstPtr[x] = color;
+#else
+			// carefully written like this to generate conditional move instructions (font data is hard to predict)
+			tmp = dstPtr[x];
+			if (srcPtr[x] != 0) tmp = color;
+			dstPtr[x] = tmp;
+#endif
 		}
 
 		srcPtr += FONT4_WIDTH;
@@ -1283,7 +1425,9 @@ static void drawNoteBig(uint32_t xPos, uint32_t yPos, int32_t ton, uint32_t colo
 	const uint8_t *ch1Ptr, *ch2Ptr, *ch3Ptr;
 	uint8_t note;
 	uint32_t *dstPtr, char1, char2, char3;
-
+#ifndef __arm__
+	uint32_t tmp;
+#endif
 	ton--;
 
 	note = noteTab1[ton];
@@ -1309,9 +1453,24 @@ static void drawNoteBig(uint32_t xPos, uint32_t yPos, int32_t ton, uint32_t colo
 	{
 		for (uint32_t x = 0; x < FONT5_CHAR_W; x++)
 		{
-			if (ch1Ptr[x]) dstPtr[(FONT5_CHAR_W * 0) + x] = color;
-			if (ch2Ptr[x]) dstPtr[(FONT5_CHAR_W * 1) + x] = color;
-			if (ch3Ptr[x]) dstPtr[(FONT5_CHAR_W * 2) + x] = color;
+#ifdef __arm__
+			if (ch1Ptr[x] != 0) dstPtr[x] = color;
+			if (ch2Ptr[x] != 0) dstPtr[FONT5_CHAR_W+x] = color;
+			if (ch3Ptr[x] != 0) dstPtr[(FONT5_CHAR_W*2)+x] = color;
+#else
+			// carefully written like this to generate conditional move instructions (font data is hard to predict)
+			tmp = dstPtr[x];
+			if (ch1Ptr[x] != 0) tmp = color;
+			dstPtr[x] = tmp;
+
+			tmp = dstPtr[FONT5_CHAR_W+x];
+			if (ch2Ptr[x] != 0) tmp = color;
+			dstPtr[FONT5_CHAR_W+x] = tmp;
+
+			tmp = dstPtr[(FONT5_CHAR_W*2)+x];
+			if (ch3Ptr[x] != 0) tmp = color;
+			dstPtr[(FONT5_CHAR_W*2)+x] = tmp;
+#endif
 		}
 
 		ch1Ptr += FONT5_WIDTH;
